.. distribute_compute_config documentation master file, created by
   sphinx-quickstart on Sat Aug 20 14:17:24 2022.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

distribute_compute_config documentation
=====================================================

.. _installation:

Installation
------------

Install with ``pip``:

.. code-block:: console

   $ pip3 install distribute_compute_config 

Main Documentation
------------------

This is the python api to the broader and more complex distributed computing system documented `here <https://fluid-dynamics-group.github.io/distribute-docs>`_.
If you have any questions about how components fit together, reading through the user guide will likely clarify them.

Contents
--------

.. toctree::

   api
   example
